==> google-cloud-bigquery-data-exchange-0.4.0.tar.gz: google-cloud-bigquery-data-exchange-0.4.0/google/cloud/bigquery_data_exchange_v1beta1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.bigquery_data_exchange import gapic_version as package_version

__version__ = package_version.__version__


from .services.analytics_hub_service import (
    AnalyticsHubServiceAsyncClient,
    AnalyticsHubServiceClient,
)
from .types.dataexchange import (
    CreateDataExchangeRequest,
    CreateListingRequest,
    DataExchange,
    DataProvider,
    DeleteDataExchangeRequest,
    DeleteListingRequest,
    DestinationDataset,
    DestinationDatasetReference,
    GetDataExchangeRequest,
    GetListingRequest,
    ListDataExchangesRequest,
    ListDataExchangesResponse,
    Listing,
    ListListingsRequest,
    ListListingsResponse,
    ListOrgDataExchangesRequest,
    ListOrgDataExchangesResponse,
    Publisher,
    SubscribeListingRequest,
    SubscribeListingResponse,
    UpdateDataExchangeRequest,
    UpdateListingRequest,
)

__all__ = (
    "AnalyticsHubServiceAsyncClient",
    "AnalyticsHubServiceClient",
    "CreateDataExchangeRequest",
    "CreateListingRequest",
    "DataExchange",
    "DataProvider",
    "DeleteDataExchangeRequest",
    "DeleteListingRequest",
    "DestinationDataset",
    "DestinationDatasetReference",
    "GetDataExchangeRequest",
    "GetListingRequest",
    "ListDataExchangesRequest",
    "ListDataExchangesResponse",
    "ListListingsRequest",
    "ListListingsResponse",
    "ListOrgDataExchangesRequest",
    "ListOrgDataExchangesResponse",
    "Listing",
    "Publisher",
    "SubscribeListingRequest",
    "SubscribeListingResponse",
    "UpdateDataExchangeRequest",
    "UpdateListingRequest",
)

==> google-cloud-bigquery-data-exchange-0.5.2.tar.gz: google-cloud-bigquery-data-exchange-0.5.2/google/cloud/bigquery_data_exchange_v1beta1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.bigquery_data_exchange_v1beta1 import gapic_version as package_version

__version__ = package_version.__version__


from .services.analytics_hub_service import (
    AnalyticsHubServiceAsyncClient,
    AnalyticsHubServiceClient,
)
from .types.dataexchange import (
    CreateDataExchangeRequest,
    CreateListingRequest,
    DataExchange,
    DataProvider,
    DeleteDataExchangeRequest,
    DeleteListingRequest,
    DestinationDataset,
    DestinationDatasetReference,
    GetDataExchangeRequest,
    GetListingRequest,
    ListDataExchangesRequest,
    ListDataExchangesResponse,
    Listing,
    ListListingsRequest,
    ListListingsResponse,
    ListOrgDataExchangesRequest,
    ListOrgDataExchangesResponse,
    Publisher,
    SubscribeListingRequest,
    SubscribeListingResponse,
    UpdateDataExchangeRequest,
    UpdateListingRequest,
)

__all__ = (
    "AnalyticsHubServiceAsyncClient",
    "AnalyticsHubServiceClient",
    "CreateDataExchangeRequest",
    "CreateListingRequest",
    "DataExchange",
    "DataProvider",
    "DeleteDataExchangeRequest",
    "DeleteListingRequest",
    "DestinationDataset",
    "DestinationDatasetReference",
    "GetDataExchangeRequest",
    "GetListingRequest",
    "ListDataExchangesRequest",
    "ListDataExchangesResponse",
    "ListListingsRequest",
    "ListListingsResponse",
    "ListOrgDataExchangesRequest",
    "ListOrgDataExchangesResponse",
    "Listing",
    "Publisher",
    "SubscribeListingRequest",
    "SubscribeListingResponse",
    "UpdateDataExchangeRequest",
    "UpdateListingRequest",
)
